@@ -28,82 +28,82 @@ class Animations : public QObject
 
 public:
     //* constructor
-    explicit Animations(QObject *);
+    explicit Animations();
 
     //* register animations corresponding to given widget, depending on its type.
-    void registerWidget(QWidget *widget) const;
+    void registerWidget(QObject *widget) const;
 
     /** unregister all animations associated to a widget */
-    void unregisterWidget(QWidget *widget) const;
+    void unregisterWidget(QObject *widget) const;
 
     //* enability engine
-    WidgetStateEngine &widgetEnabilityEngine() const
+    [[nodiscard]] WidgetStateEngine &widgetEnabilityEngine() const
     {
         return *_widgetEnabilityEngine;
     }
 
     //* abstractButton engine
-    WidgetStateEngine &widgetStateEngine() const
+    [[nodiscard]] WidgetStateEngine &widgetStateEngine() const
     {
         return *_widgetStateEngine;
     }
 
     //* editable combobox arrow hover engine
-    WidgetStateEngine &comboBoxEngine() const
+    [[nodiscard]] WidgetStateEngine &comboBoxEngine() const
     {
         return *_comboBoxEngine;
     }
 
     //* Tool buttons arrow hover engine
-    WidgetStateEngine &toolButtonEngine() const
+    [[nodiscard]] WidgetStateEngine &toolButtonEngine() const
     {
         return *_toolButtonEngine;
     }
 
     //* item view engine
-    WidgetStateEngine &inputWidgetEngine() const
+    [[nodiscard]] WidgetStateEngine &inputWidgetEngine() const
     {
         return *_inputWidgetEngine;
     }
 
     //* busy indicator
-    BusyIndicatorEngine &busyIndicatorEngine() const
+    [[nodiscard]] BusyIndicatorEngine &busyIndicatorEngine() const
     {
         return *_busyIndicatorEngine;
     }
 
     //* header view engine
-    HeaderViewEngine &headerViewEngine() const
+    [[nodiscard]] HeaderViewEngine &headerViewEngine() const
     {
         return *_headerViewEngine;
     }
 
     //* scrollbar engine
-    ScrollBarEngine &scrollBarEngine() const
+    [[nodiscard]] ScrollBarEngine &scrollBarEngine() const
     {
         return *_scrollBarEngine;
     }
 
     //* dial engine
-    DialEngine &dialEngine() const
+    [[nodiscard]] DialEngine &dialEngine() const
     {
         return *_dialEngine;
     }
 
     //* spinbox engine
-    SpinBoxEngine &spinBoxEngine() const
+    [[nodiscard]] SpinBoxEngine &spinBoxEngine() const
     {
         return *_spinBoxEngine;
     }
 
     //* tabbar
-    TabBarEngine &tabBarEngine() const
+    [[nodiscard]] TabBarEngine &tabBarEngine() const
     {
         return *_tabBarEngine;
     }
 
     //* toolbox
-    ToolBoxEngine &toolBoxEngine() const
+    [[nodiscard]] ToolBoxEngine &toolBoxEngine() const
     {
         return *_toolBoxEngine;
     }
