@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef breezescrollbar_data_h
-#define breezescrollbar_data_h
+#pragma once
 
 #include "breezewidgetstatedata.h"
 
@@ -23,7 +22,7 @@ class ScrollBarData : public WidgetStateData
 
 public:
     //* constructor
-    ScrollBarData(QObject *parent, QWidget *target, int);
+    ScrollBarData(QObject *parent, QObject *target, int duration);
 
     //* event filter
     bool eventFilter(QObject *, QEvent *) override;
@@ -271,5 +270,3 @@ private:
 };
 
 }
-
-#endif
